==> evolution-1.4.11.zip: evolution-1.4.11/manager/includes/lang/errormsg/japanese-utf8.inc.php <==
<?php
/**
 * MODX error messages language file
 *
 * @version 1.0.13
 * @date 31/12/2013
 *
 * @language Japanese
 * @package modx
 * @subpackage manager
 *
 * Please commit your language changes on Transifex (https://www.transifex.com/projects/p/modx-evolution/) or on GitHub (https://github.com/modxcms/evolution).
 */
$_lang["No errors occured."] = "エラーはありません。";
$_lang["An error occured!"] = "エラーが発生しました。";
$_lang["You don't have enough privileges for this action!"] = "この操作を行なう権限がありません。";
$_lang["ID passed in request is NaN!"] = "ID passed in request is NaN!";
$_lang["The document is locked!"] = "リソースがロックされています。";
$_lang["Too many results returned from database!"] = "データベースからの返り値が多過ぎます。内部処理に問題があります。";
$_lang["Not enough/ no results returned from database!"] = "Not enough/ no results returned from database!";
$_lang["Couldn't find parent document's name!"] = "Couldn't find parent document's name!";
$_lang["Logging error!"] = "Logging error!";
$_lang["Table to optimise not found in request!"] = "Table to optimise not found in request!";
$_lang["No settings found in request!"] = "No settings found in request!";
$_lang["The document must have a title!"] = "The document must have a title!";
$_lang["No user selected as recipient of this message!"] = "No user selected as recipient of this message!";
$_lang["No group selected as recipient of this message!"] = "No group selected as recipient of this message!";
$_lang["The document was not found!"] = "リソースが見つかりません。";
$_lang["Double action (GET & POST) posted!"] = "Double action (GET & POST) posted!";
$_lang["Document cannot be it's own parent!"] = "自分自身を親として指定することはできません。";
$_lang["Document's ID not passed in request!"] = "Document's ID not passed in request!";
$_lang["New parent not set in request!"] = "New parent not set in request!";
$_lang["don't know the user!" ] = "ログイン名またはパスワードが間違っています。";
$_lang["wrong password!"] = "ログイン名またはパスワードが間違っています。";
$_lang["Due to too many failed logins, you have been blocked!"] = "ログインを数回失敗したため、一時的にアクセスが制限されています。";
$_lang["You are blocked and cannot log in!"] = "ログインをブロックされています。";
$_lang["You are blocked and cannot log in! Please try again later."] = "ログインをブロックされています。しばらくたってから再び試してください。";
$_lang["The security code you entered didn't validate! Please try to login again!"] = "入力されたセキュリティコードが間違っています。";

==> evolution-1.4.21.zip: evolution-1.4.21/manager/includes/lang/errormsg/japanese-utf8.inc.php <==
<?php
/**
 * MODX error messages language file
 *
 * @version 1.0.13
 * @date 31/12/2013
 *
 * @language Japanese
 * @package modx
 * @subpackage manager
 *
 * Please commit your language changes on Transifex (https://www.transifex.com/projects/p/modx-evolution/) or on GitHub (https://github.com/modxcms/evolution).
 */
$_lang["No errors occured."] = "エラーはありません。";
$_lang["An error occured!"] = "エラーが発生しました。";
$_lang["You don't have enough privileges for this action!"] = "この操作を行なう権限がありません。";
$_lang["ID passed in request is NaN!"] = "ID passed in request is NaN!";
$_lang["The document is locked!"] = "リソースがロックされています。";
$_lang["Too many results returned from database!"] = "データベースからの返り値が多過ぎます。内部処理に問題があります。";
$_lang["Not enough/ no results returned from database!"] = "Not enough/ no results returned from database!";
$_lang["Couldn't find parent document's name!"] = "Couldn't find parent document's name!";
$_lang["Logging error!"] = "Logging error!";
$_lang["Table to optimise not found in request!"] = "Table to optimise not found in request!";
$_lang["No settings found in request!"] = "No settings found in request!";
$_lang["The document must have a title!"] = "The document must have a title!";
$_lang["No user selected as recipient of this message!"] = "No user selected as recipient of this message!";
$_lang["No group selected as recipient of this message!"] = "No group selected as recipient of this message!";
$_lang["The document was not found!"] = "リソースが見つかりません。";
$_lang["Double action (GET & POST) posted!"] = "Double action (GET & POST) posted!";
$_lang["Document cannot be it's own parent!"] = "自分自身を親として指定することはできません。";
$_lang["Document's ID not passed in request!"] = "Document's ID not passed in request!";
$_lang["New parent not set in request!"] = "New parent not set in request!";
$_lang["don't know the user!" ] = "間違ったユーザー名またはパスワードが入力されたか、ブロックされました！";
$_lang["wrong password!"] = "間違ったユーザー名またはパスワードが入力されたか、ブロックされました！";
$_lang["Due to too many failed logins, you have been blocked!"] = "間違ったユーザー名またはパスワードが入力されたか、ブロックされました！";
$_lang["You are blocked and cannot log in!"] = "間違ったユーザー名またはパスワードが入力されたか、ブロックされました！";
$_lang["You are blocked and cannot log in! Please try again later."] = "間違ったユーザー名またはパスワードが入力されたか、ブロックされました！";
$_lang["The security code you entered didn't validate! Please try to login again!"] = "入力されたセキュリティコードが間違っています。";
